#
# spec file for package ptyxis
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ptyxis
Version:        47.10
Release:        1.2
Summary:        A terminal for GNOME with first-class support for containers
License:        GPL-3.0-or-later
URL:            https://www.gnome.org
Source:         %{name}-%{version}.tar.zst
BuildRequires:  desktop-file-utils
BuildRequires:  meson >= 0.64.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.80
BuildRequires:  pkgconfig(gtk4) >= 4.14
BuildRequires:  pkgconfig(json-glib-1.0) >= 1.6
BuildRequires:  pkgconfig(libadwaita-1) >= 1.6
BuildRequires:  pkgconfig(libportal-gtk4)
BuildRequires:  pkgconfig(vte-2.91-gtk4) >= 0.76

%description
Ptyxis is a terminal for GNOME with first-class support for containers.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%find_lang %{name} %{?no_lang_C}

%check
%meson_test

%files
%license COPYING
%{_bindir}/ptyxis
%{_mandir}/man1/ptyxis.1%{?ext_man}
%{_libexecdir}/ptyxis-agent
%{_datadir}/applications/org.gnome.Ptyxis.desktop
%{_datadir}/dbus-1/services/org.gnome.Ptyxis.service
%{_datadir}/glib-2.0/schemas/org.gnome.Ptyxis.gschema.xml
%{_datadir}/icons/hicolor/*/apps/*
%{_datadir}/metainfo/org.gnome.Ptyxis.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Fri Feb 14 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.10:
  + Fix appinfo for automated CI
  + Fix "Move to New Window" action when right clicking on tabs
    where the window may get created without an application
    instance.
  + Fullscreen button layout and style to match platform
    expectations.
  + Fix exit code when activating a previous Ptyxis instance.
  + Add support for Debian's x-terminal-emulator.
* Tue Jan 28 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.8:
  + Open shell on remote host using SSH when sftp:// URIs are
    opened via Nautilus or otherwise.
  + Ensure window size is not inherited when restore-window-size is
    disabled.
* Sat Jan 18 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.7:
  + Fixes to tracking podman-based containers.
  + Add support for setting CursorForeground in palette files.
  + Improve fullscreen mode to use the same interaction model as
    Epiphany which animate into view based on mouse pointer.
  + Add a High Contrast oriented palette based on GNOME palette.
  + Set PWD when spawning shells to improve usage within symlinks.
* Thu Dec  5 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.6:
  + Many separate light/dark palettes have been merged so that they
    may switch between light/dark like the core palettes.
  + A new GSetting has been added to allow controlling
    middle-mouse-click behavior.
  + Use the minimum size request for the header bar to prevent
  - -title from creating larger than necessary windows.
  + Fix brightness of GNOME palette on dark mode to match palette
    index 7.
  + Revert a workaround for reverse video cursor which caused some
    fg/bg issues in some terminal applications.
  + Ensure all palettes specify Cursor color which makes the
    previous mitigation unnecessary.
  + Allow the window to grow/shrink when dragging a tab out of the
    tab bar.
  + Send SIGHUP before SIGKILL upon forcing a tab to quit so that
    shells like bash may save history.
  + Mark mosh/mosh-client as "remote" processes.
* Thu Nov 21 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.5:
  + Bump the FD soft limit to the max allowed, now that there are
    more FDs open for Vulkan shader caches.
  + Fix monitoring of podman for changes which fixes auto-discovery
    of quadlets in systemd --user services.
  + Fix disposal of tabs without a foreground process upon closing
    a Ptyxis window.
  + Robustness fixes in icon discover for tabs with containers
  + Robustness fixes in checking for active container
  + Fix scrolling within close-tabs dialog
* Tue Oct 29 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.4:
  + Work around Podman in `--additional-flags` parsing to fix
    execution of distrobox containers.
  + Prioritize "manager":"distrobox" over
    "com.github.containers.toolbox" label because F41 images
    created by distrobox are, for some reason, setting the toolbox
    label id.
  + Fix raising of window when activating shell notification.
  + Override distro-theming for `vte-terminal` CSS element. This
    fixes styling on Ubuntu-based systems, but possibly others.
* Sat Oct 19 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.3:
  + Fix race condition in connecting to exited/signaled D-Bus
    signals from PtyxisIpcProcess. This fixes situations where
    quick running scripts exit before attaching to said signals,
    generally during application startup.
  + Fix --preserve-fds=0 error on distrobox.
  + Check tiled state in new-window action to start in windowed
    mode.
  + Fix detach-tab shortcut.
  + Updated translations.
* Fri Oct  4 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.2:
  + Fix closing window title dialog with Return/Enter
  + Fix naming of Ubuntu palette
  + Allow setting shortcuts with Fn keys on Macbooks
  + Fix some solarized palette inconsistencies
  + Updated translations.
* Wed Sep 25 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 47.1:
  + More clipboard fixes for initial state tracking.
  + Handle shell detection when directory slash is omitted.
  + Exit cleanly when ptyxis-agent exits.
  + Fix VteRegex warning from the search bar.
  + Fix potential leak of VteTerminal instances.
  + Update gruvbox light/dark scheme.
  + Updated translations.
* Sat Sep 14 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + Implement application open file vfunc to work with Nautilus
  + Fix inintial clipboard action state
  + Fix various styling issues
  + Rename Clone of Ubuntu to Ubuntu at request of Ubuntu
  + Try to adjust window size to keep grid size the same when
    adding or removing tabs
* Wed Sep 11 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.rc:
  + Ctrl+shift+w now set as default shortcut for closing a tab,
    matching GNOME Terminal.
  + Preferences window improvements.
  + Updated GNOME Terminal palettes.
  + UI changes to improve screen reader support.
  + Make CSS provider priority less than the GTK inspector.
  + Styling improvements to match Builder and Text Editor.
  + Fix support for enabling login shells.
  + Convenience API for distros which require downstream patching
    for current directory tracking (such as Debian).
  + Fix container tracking and notifications via termprops.
  + Show opacity toggle if the setting has been changed.
  + Handle new tab creation when directory is in a GVFS FUSE path.
  + Reduce agent poll priority when ^C is pressed.
  + Overview styling and live-preview improvements to updated
    immediately when preferences changes.
  + Fix missing shortcut bindings for reset and reset-and-clear.
- Changes from version 47.beta:
  + Ptyxis no longer requires patches to VTE when using a recent
    VTE git tag for GNOME 47.
  + Legacy libc compat was dropped for 32-bit x86 as it is
    unnecessary.
  + Window pallete and styling improvements to match GNOME 47
    styling.
  + A new gsetting to disable padding around the terminal, at the
    cost of runtime performance.
  + Updated translations.
- Changes from version 47.alpha:
  + Many updates for GNOME HIG across dialogs and widgetry.
  + Ptyxis can run the ptyxis-agent inside the sandbox if we fail
    to run on the host. That comes with drawbacks but at least
    keeps the application working in those scenarios.
  + The build system supports some whitebox renaming allowing it to
    be called "Terminal" in some situations. Distributions shipping
    Ptyxis as their terminal may be encouraged to use that.
    Branding is also reduced to less dramatic styling.
  + Many fixes for Podman, Toolbox, and Distrobox.
  + Fallback to `sh` if we cannot locate the shell specified in
    /etc/passwd.
  + Improvements to the tab parking lot so that processes are
    properly exited.
  + Notification improvements.
  + Port Ptyxis to use the new VTE "termprops" feature. This
    requires a newer VTE than is currently released but is
    anticipated shortly. This reduces the number of patches
    required by Ptyxis (and eventually Fedora) to a single small
    patch for vte.sh.in.
  + New palettes styles.
  + Many new command line options and improved support for
    combining them.
  + Updated translations.
* Fri Aug  9 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 46.6:
  + Use a lower value for CSS provider so inspector CSS changes can
    occur at a higher priority.
  + Drop libc compat mode for x86, this is unnecessary now.
  + Fix login-shell toggle in preferences.
  + Show opacity control if the value is currently < 100%%.
  + Updated translations.
* Tue Jul  9 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 46.5:
  + Ptyxis (1) man page has been added.
* Mon Jul  1 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.4:
  + Fix clear selection shortcut binding
  + Only allow a single palette to affect window dressing at a
    time, fixing a situation where the last palette selected takes
    precedence.
  + Work around misconfigured /etc/passwd in containers.
* Tue Jun 11 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.3:
  + stdin in child processes defaults to blocking mode as is
    generally expected of terminals.
  + Ignore tab respawn warnings when custom commands are used and
    they exited nominally.
  + Various build system and metainfo updates.
  + Updated translations.
* Thu Jun  6 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.2+13:
  + Update metainfo.
  + Updated translations.
* Mon May 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.2:
  + Additional troubleshooting data has been added to the about
    dialog to help users provide useful information.
  + Patches for `vte.sh` are updated to match changes I made for
    Fedora 40 which properly support PROMPT_COMMAND as a bash
    array.
  + Patches for a11y are updated to apply against vte-0-76 branch.
  + Ensure tabs are force-quit when timing out in the parking lot.
  + Some build system rework has occurred for Ptyxis to be compiled
    with alternate app-id and/or gschema identifiers.
  + The build system will now enforce specific linked versions of
    GLib, GTK, and libadwaita using min/max version macros.
* Sat Apr 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update file list.
- Split out lang package.
* Thu Apr 11 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.1:
  + Ensure run contexts start with full environment which fixes an
    issue with running podman in some configurations.
  + Fix initial tab icon state.
  . Podman integration now uses PtyxisRunContext to better
    trampoline into the target container.
* Sat Mar 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Initial package, version 46.0.
